@@ -102,8 +102,8 @@ class Plot:
        :include-source: True
 
        >>> from sympy import symbols, sin, cos, log, S
-       >>> from spb import plot
-       >>> x = symbols("x")
+       >>> from spb import plot, plot3d
+       >>> x, y = symbols("x, y")
        >>> p1 = plot(sin(x), cos(x), show=False)
        >>> p2 = plot(sin(x) * cos(x), log(x), show=False)
        >>> p3 = p1 + p2
@@ -120,7 +120,7 @@ class Plot:
        >>> p1 = plot(sin(x), cos(x), show=False)
        >>> xx, yy = p1[0].get_data()
 
-    Creating a new backend with a custom colorloop:
+    Create a new backend with a custom colorloop:
 
     .. plot::
        :context: close-figs
@@ -132,6 +132,23 @@ class Plot:
        ...     colorloop = ["r", "g", "b"]
        >>> plot(sin(x) / 3, sin(x) * S(2) / 3, sin(x), backend=MBchild)
 
+    Create a new backend with custom color maps for 3D plots. Note that
+    it's possible to use Plotly/Colorcet/Matplotlib colormaps interchangeably.
+
+    .. plot::
+       :context: close-figs
+       :format: doctest
+       :include-source: True
+
+       >>> from spb.backends.matplotlib import MB
+       >>> import colorcet as cc
+       >>> class MBchild(MB):
+       ...     colormaps = ["plotly3", cc.bmy]
+       >>> plot3d(
+       ...     (cos(x**2 + y**2), (x, -2, 0), (y, -2, 2)),
+       ...     (cos(x**2 + y**2), (x, 0, 2), (y, -2, 2)),
+       ...     backend=MBchild, n1=25, n2=50)
+
 
     See also
     ========
@@ -210,10 +227,6 @@ class Plot:
                 series.extend(_series)
             self._series = series
 
-        # The user can choose to use the standard color map loop, or
-        # set/provide a solid color loop (for the surface color).
-        self._use_cm = kwargs.get("use_cm", True)
-
         # auto-legend: if more than 1 data series has been provided and the
         # user has not set legend=False, then show the legend for better
         # clarity.
@@ -221,8 +234,7 @@ class Plot:
         if not self.legend:
             self.legend = False
             if (len(self._series) > 1) or (
-                any(s.is_parametric for s in self.series) and self._use_cm
-            ):
+                any(s.is_parametric and s.use_cm for s in self.series)):
                 # don't show the legend if `plot_piecewise` created this
                 # backend
                 if not ("process_piecewise" in kwargs.keys()):
@@ -271,7 +283,6 @@ class Plot:
             yscale=self.yscale,
             zscale=self.zscale,
             detect_poles=self.detect_poles,
-            use_cm=self._use_cm,
             legend=self.legend,
             xlim=self.xlim,
             ylim=self.ylim,
