@@ -20,13 +20,17 @@ def _hardcoded_defaults():
     return dict(
         # Find more Plotly themes at the following page:
         # https://plotly.com/python/templates/
-        plotly={"theme": "seaborn"},
+        plotly={
+            "theme": "seaborn",
+            "grid": True
+        },
         # Find more Bokeh themes at the following page:
         # https://docs.bokeh.org/en/latest/docs/reference/themes.html
         bokeh={
             "theme": "caliber",
             "sizing_mode": "stretch_width",
             "update_event": True,
+            "grid": True,
             "show_minor_grid": True,
             "minor_grid_line_alpha": 0.6,
             "minor_grid_line_dash": [2, 2],
@@ -34,7 +38,8 @@ def _hardcoded_defaults():
         k3d={
             "bg_color": 0xFFFFFF,       # 3620427
             "grid_color": 0xE6E6E6,     # 0x888888
-            "label_color": 0x444444     # 0xDDDDDD
+            "label_color": 0x444444,    # 0xDDDDDD
+            "grid": True
         },
         matplotlib={
             "axis_center": None,  # "auto", "center"
@@ -48,7 +53,8 @@ def _hardcoded_defaults():
             "coloring": "a"
         },
         interactive={
-            "use_latex": True
+            "use_latex": True,
+            "throttled": False
         }
     )
 
@@ -137,12 +143,13 @@ def _load_settings():
 
 
 def set_defaults(cfg):
-    """Set the default options for the plotting backends.
+    """Set the default options for the plotting backends and save them to
+    a file.
 
     Parameters
     ==========
-        cfg : dict
-            Dictionary containing the new values
+    cfg : dict
+        Dictionary containing the new values
 
     Examples
     ========
@@ -155,6 +162,20 @@ def set_defaults(cfg):
         >>> cfg["backend_2D"] = "matplotlib"
         >>> set_defaults(cfg)
 
+    Notes
+    =====
+
+    This plotting module uses the `appdir` module [#fn1]_ to determine the
+    best location where to save the settings. It will save a human readable
+    `config.json` file, which SHOULD NOT be modified directly with a text
+    editor.
+    Use the ``set_defaults`` function to modify the configuration settings!
+
+    References
+    ==========
+
+    .. [#fn1] https://github.com/ActiveState/appdirs
+
     """
     with open(file_path, "w", encoding="utf-8") as f:
         json.dump(cfg, f, ensure_ascii=False, indent=4)
