@@ -24,7 +24,7 @@ from sympy.concrete.summations import Sum
 from sympy.functions.elementary.complexes import sign
 from sympy.functions.elementary.piecewise import Piecewise, piecewise_fold
 from sympy.sets.sets import EmptySet, FiniteSet, Interval, Union
-from spb.backends.base_backend import Plot
+from spb.defaults import TWO_D_B, THREE_D_B
 from spb.utils import _plot_sympify, _check_arguments, _unpack_args
 from spb.series import (
     LineOver1DRangeSeries, Parametric2DLineSeries, Parametric3DLineSeries,
@@ -373,7 +373,7 @@ def plot(*args, show=True, **kwargs):
        :format: doctest
        :include-source: True
 
-       >>> from sympy import symbols, sin, pi
+       >>> from sympy import symbols, sin, pi, tan
        >>> from spb import plot
        >>> x, y = symbols('x, y')
 
@@ -452,6 +452,18 @@ def plot(*args, show=True, **kwargs):
        Plot object containing:
        [0]: cartesian line: Sum(1/x, (x, 1, y)) for y over (2.0, 10.0)
 
+    Singularity detection:
+
+    .. plot::
+       :context: close-figs
+       :format: doctest
+       :include-source: True
+
+       >>> plot(tan(x), (x, -10, 10), adaptive_goal=0.001,
+       ...     detect_poles=True, ylim=(-7, 7))
+       Plot object containing:
+       [0]: cartesian line: tan(x) for x over (-10.0, 10.0)
+
 
     References
     ==========
@@ -465,28 +477,26 @@ def plot(*args, show=True, **kwargs):
     plot3d_parametric_surface, plot_implicit, plot_geometry, plot_piecewise
 
     """
-    from spb.defaults import TWO_D_B
-
     args = _plot_sympify(args)
     free = set()
     for a in args:
         if isinstance(a, Expr):
             free |= a.free_symbols
-            if len(free) > 1:
-                raise ValueError(
-                    "The same variable should be used in all "
-                    "univariate expressions being plotted."
-                )
+            # if len(free) > 1:
+            #     raise ValueError(
+            #         "The same variable should be used in all "
+            #         "univariate expressions being plotted."
+            #     )
     x = free.pop() if free else Symbol("x")
-    kwargs.setdefault("backend", TWO_D_B)
+
     kwargs.setdefault("xlabel", x.name)
     kwargs.setdefault("ylabel", "f(%s)" % x.name)
     kwargs = _set_discretization_points(kwargs, LineOver1DRangeSeries)
     series = []
     plot_expr = _check_arguments(args, 1, 1)
     series = _build_line_series(*plot_expr, **kwargs)
-
-    plots = Plot(*series, **kwargs)
+    Backend = kwargs.pop("backend", TWO_D_B)
+    plots = Backend(*series, **kwargs)
     if show:
         plots.show()
     return plots
@@ -599,6 +609,10 @@ def plot_parametric(*args, show=True, **kwargs):
         Title of the plot. It is set to the latex representation of
         the expression, if the plot has only one expression.
 
+    use_cm : boolean, optional
+        If True, apply a color map to the parametric lines.
+        If False, solid colors will be used instead. Default to True.
+
     xlabel : str, optional
         Label for the x-axis.
 
@@ -629,18 +643,8 @@ def plot_parametric(*args, show=True, **kwargs):
        >>> from spb.functions import plot_parametric
        >>> u, v = symbols('u, v')
 
-    A parametric plot with a single expression:
-
-    .. plot::
-       :context: close-figs
-       :format: doctest
-       :include-source: True
-
-       >>> plot_parametric((cos(u), sin(u)), (u, -5, 5))
-       Plot object containing:
-       [0]: parametric cartesian line: (cos(u), sin(u)) for u over (-5.0, 5.0)
-
-    A parametric plot of a Hypotrochoid using an equal aspect ratio:
+    A parametric plot of a single expression (a Hypotrochoid using an equal
+    aspect ratio):
 
     .. plot::
        :context: close-figs
@@ -694,15 +698,13 @@ def plot_parametric(*args, show=True, **kwargs):
     plot3d_parametric_surface, plot_implicit, plot_geometry, plot_piecewise
 
     """
-    from spb.defaults import TWO_D_B
-
     args = _plot_sympify(args)
     series = []
-    kwargs.setdefault("backend", TWO_D_B)
     kwargs = _set_discretization_points(kwargs, Parametric2DLineSeries)
     plot_expr = _check_arguments(args, 2, 1)
     series = [Parametric2DLineSeries(*arg, **kwargs) for arg in plot_expr]
-    plots = Plot(*series, **kwargs)
+    Backend = kwargs.pop("backend", TWO_D_B)
+    plots = Backend(*series, **kwargs)
     if show:
         plots.show()
     return plots
@@ -804,6 +806,10 @@ def plot3d_parametric_line(*args, show=True, **kwargs):
         Title of the plot. It is set to the latex representation of
         the expression, if the plot has only one expression.
 
+    use_cm : boolean, optional
+        If True, apply a color map to the parametric lines.
+        If False, solid colors will be used instead. Default to True.
+
     xlabel : str, optional
         Label for the x-axis.
 
@@ -872,10 +878,7 @@ def plot3d_parametric_line(*args, show=True, **kwargs):
     plot_implicit, plot_geometry, plot_parametric, plot_piecewise
 
     """
-    from spb.defaults import THREE_D_B
-
     args = _plot_sympify(args)
-    kwargs.setdefault("backend", THREE_D_B)
     kwargs = _set_discretization_points(kwargs, Parametric3DLineSeries)
     series = []
     plot_expr = _check_arguments(args, 3, 1)
@@ -883,7 +886,8 @@ def plot3d_parametric_line(*args, show=True, **kwargs):
     kwargs.setdefault("xlabel", "x")
     kwargs.setdefault("ylabel", "y")
     kwargs.setdefault("zlabel", "z")
-    plots = Plot(*series, **kwargs)
+    Backend = kwargs.pop("backend", THREE_D_B)
+    plots = Backend(*series, **kwargs)
     if show:
         plots.show()
     return plots
@@ -990,6 +994,10 @@ def plot3d(*args, show=True, **kwargs):
         Title of the plot. It is set to the latex representation of
         the expression, if the plot has only one expression.
 
+    use_cm : boolean, optional
+        If True, apply a color map to the surface.
+        If False, solid colors will be used instead. Default to True.
+
     xlabel : str, optional
         Label for the x-axis.
 
@@ -1071,10 +1079,7 @@ def plot3d(*args, show=True, **kwargs):
     plot3d_parametric_surface, plot_implicit, plot_geometry, plot_piecewise
 
     """
-    from spb.defaults import THREE_D_B
-
     args = _plot_sympify(args)
-    kwargs.setdefault("backend", THREE_D_B)
     kwargs = _set_discretization_points(kwargs, SurfaceOver2DRangeSeries)
     series = []
     plot_expr = _check_arguments(args, 1, 2)
@@ -1084,7 +1089,8 @@ def plot3d(*args, show=True, **kwargs):
     kwargs.setdefault("xlabel", xlabel)
     kwargs.setdefault("ylabel", ylabel)
     kwargs.setdefault("zlabel", "f(%s, %s)" % (xlabel, ylabel))
-    plots = Plot(*series, **kwargs)
+    Backend = kwargs.pop("backend", THREE_D_B)
+    plots = Backend(*series, **kwargs)
     if show:
         plots.show()
     return plots
@@ -1165,6 +1171,10 @@ def plot3d_parametric_surface(*args, show=True, **kwargs):
         Title of the plot. It is set to the latex representation of
         the expression, if the plot has only one expression.
 
+    use_cm : boolean, optional
+        If True, apply a color map to the surface.
+        If False, solid colors will be used instead. Default to True.
+
     xlabel : str, optional
         Label for the x-axis.
 
@@ -1223,17 +1233,15 @@ def plot3d_parametric_surface(*args, show=True, **kwargs):
     plot3d_parametric_line, plot_implicit, plot_geometry, plot_piecewise
 
     """
-    from spb.defaults import THREE_D_B
-
     args = _plot_sympify(args)
-    kwargs.setdefault("backend", THREE_D_B)
     kwargs = _set_discretization_points(kwargs, ParametricSurfaceSeries)
     plot_expr = _check_arguments(args, 3, 2)
     kwargs.setdefault("xlabel", "x")
     kwargs.setdefault("ylabel", "y")
     kwargs.setdefault("zlabel", "z")
     series = [ParametricSurfaceSeries(*arg, **kwargs) for arg in plot_expr]
-    plots = Plot(*series, **kwargs)
+    Backend = kwargs.pop("backend", THREE_D_B)
+    plots = Backend(*series, **kwargs)
     if show:
         plots.show()
     return plots
@@ -1290,10 +1298,7 @@ def plot_contour(*args, show=True, **kwargs):
     plot3d_parametric_surface, plot_implicit, plot_geometry, plot_piecewise
 
     """
-    from spb.defaults import TWO_D_B
-
     args = _plot_sympify(args)
-    kwargs.setdefault("backend", TWO_D_B)
     kwargs = _set_discretization_points(kwargs, ContourSeries)
     plot_expr = _check_arguments(args, 1, 2)
     series = [ContourSeries(*arg, **kwargs) for arg in plot_expr]
@@ -1301,7 +1306,8 @@ def plot_contour(*args, show=True, **kwargs):
     ylabel = series[0].var_y.name
     kwargs.setdefault("xlabel", xlabel)
     kwargs.setdefault("ylabel", ylabel)
-    plot_contours = Plot(*series, **kwargs)
+    Backend = kwargs.pop("backend", TWO_D_B)
+    plot_contours = Backend(*series, **kwargs)
     if show:
         plot_contours.show()
     return plot_contours
@@ -1325,7 +1331,7 @@ def plot_implicit(*args, show=True, **kwargs):
         expr : Expr, Relational, BooleanFunction
             The equation / inequality that is to be plotted.
 
-        ranges : tuples
+        ranges : tuples or Symbol
             Two tuple denoting the discretization domain, for example:
             `(x, -10, 10), (y, -10, 10)`
             To get a correct plot, at least the horizontal range must be
@@ -1333,6 +1339,10 @@ def plot_implicit(*args, show=True, **kwargs):
             expression will be assigned in the order they are sorted, which
             could 'invert' the axis.
 
+            Alternatively, a single Symbol corresponding to the horizontal
+            axis must be provided, which will be internally converted to a
+            range `(sym, -10, 10)`.
+
         label : str, optional
             The name of the expression to be eventually shown on the legend.
             If not provided, the string representation of `expr` will be used.
@@ -1398,37 +1408,35 @@ def plot_implicit(*args, show=True, **kwargs):
         >>> from spb.functions import plot_implicit
         >>> x, y = symbols('x y')
 
-    Without any ranges for the symbols in the expression:
+    Providing only the symbol for the horizontal axis:
 
     .. plot::
         :context: close-figs
         :format: doctest
         :include-source: True
 
-        >>> p1 = plot_implicit(Eq(x**2 + y**2, 5))
+        >>> plot_implicit(x - 1, x)
 
-    With the range for the symbols:
+    With the range for both symbols:
 
     .. plot::
         :context: close-figs
         :format: doctest
         :include-source: True
 
-        >>> p2 = plot_implicit(
-        ...     Eq(x**2 + y**2, 3), (x, -3, 3), (y, -3, 3))
+        >>> plot_implicit(Eq(x**2 + y**2, 3), (x, -3, 3), (y, -3, 3))
 
-    Using mesh grid without adaptive meshing with number of points
-    specified:
+    Specify the number of discretization points for the contour algorithm:
 
     .. plot::
         :context: close-figs
         :format: doctest
         :include-source: True
 
-        >>> p3 = plot_implicit(
+        >>> plot_implicit(
         ...     (x**2 + y**2 - 1)**3 - x**2 * y**3,
         ...     (x, -1.5, 1.5), (y, -1.5, 1.5),
-        ...     n = 1000)
+        ...     n = 500)
 
     Using adaptive meshing and Boolean expressions:
 
@@ -1437,7 +1445,7 @@ def plot_implicit(*args, show=True, **kwargs):
         :format: doctest
         :include-source: True
 
-        >>> p4 = plot_implicit(
+        >>> plot_implicit(
         ...     Eq(y, sin(x)) & (y > 0),
         ...     Eq(y, sin(x)) & (y < 0),
         ...     (x, -2 * pi, 2 * pi), (y, -4, 4),
@@ -1450,9 +1458,9 @@ def plot_implicit(*args, show=True, **kwargs):
         :format: doctest
         :include-source: True
 
-        >>> p5 = plot_implicit(
+        >>> plot_implicit(
         ...     Eq(x**2 + y**2, 5), (x, -4, 4), (y, -4, 4),
-        ...     adaptive=True, depth = 2)
+        ...     adaptive=True, depth=2)
 
     Plotting regions:
 
@@ -1461,7 +1469,7 @@ def plot_implicit(*args, show=True, **kwargs):
         :format: doctest
         :include-source: True
 
-        >>> p6 = plot_implicit(y > x**2, (x, -5, 5))
+        >>> plot_implicit(y > x**2, (x, -5, 5))
 
     See Also
     ========
@@ -1470,7 +1478,15 @@ def plot_implicit(*args, show=True, **kwargs):
     plot3d_parametric_surface, plot_geometry
 
     """
-    from spb.defaults import TWO_D_B
+    # if the user is plotting a single expression, then he can pass in one
+    # or two symbols to sort the axis. Ranges will then be automatically
+    # created.
+    args = list(args)
+    if (len(args) == 2) and isinstance(args[1], Symbol):
+        args[1] = Tuple(args[1], -10, 10)
+    if (len(args) == 3) and isinstance(args[1], Symbol) and isinstance(args[2], Symbol):
+        args[1] = Tuple(args[1], -10, 10)
+        args[2] = Tuple(args[2], -10, 10)
 
     args = _plot_sympify(args)
     args = _check_arguments(args, 1, 2)
@@ -1485,6 +1501,7 @@ def plot_implicit(*args, show=True, **kwargs):
     )
 
     series = []
+    # compute the area that should be visible on the plot
     xmin, xmax, ymin, ymax = oo, -oo, oo, -oo
     for a in args:
         s = ImplicitSeries(*a, **series_kw)
@@ -1498,12 +1515,13 @@ def plot_implicit(*args, show=True, **kwargs):
             ymax = s.end_y
         series.append(s)
 
-    kwargs.setdefault("backend", TWO_D_B)
+    # kwargs.setdefault("backend", TWO_D_B)
     kwargs.setdefault("xlim", (xmin, xmax))
     kwargs.setdefault("ylim", (ymin, ymax))
     kwargs.setdefault("xlabel", series[-1].var_x.name)
     kwargs.setdefault("ylabel", series[-1].var_y.name)
-    p = Plot(*series, **kwargs)
+    Backend = kwargs.pop("backend", TWO_D_B)
+    p = Backend(*series, **kwargs)
     if show:
         p.show()
     return p
@@ -1724,8 +1742,6 @@ def plot_geometry(*args, show=True, **kwargs):
        [1]: geometry entity: Line3D(Point3D(-2, -3, -4), Point3D(2, 3, 4))
        [2]: plane series over (x, -5, 5), (y, -4, 4), (z, -10, 10)
     """
-    from spb.defaults import TWO_D_B, THREE_D_B
-
     args = _plot_sympify(args)
 
     series = []
@@ -1747,12 +1763,8 @@ def plot_geometry(*args, show=True, **kwargs):
     if ("aspect" not in kwargs) and (not any_3D):
         kwargs["aspect"] = "equal"
 
-    if any_3D:
-        kwargs.setdefault("backend", THREE_D_B)
-    else:
-        kwargs.setdefault("backend", TWO_D_B)
-
-    p = Plot(*series, **kwargs)
+    Backend = kwargs.pop("backend", THREE_D_B if any_3D else TWO_D_B)
+    p = Backend(*series, **kwargs)
     if show:
         p.show()
     return p
@@ -1846,7 +1858,7 @@ def plot_list(*args, show=True, **kwargs):
     ========
 
     .. plot::
-       :context: close-figs
+       :context: reset
        :format: doctest
        :include-source: True
 
@@ -1883,8 +1895,6 @@ def plot_list(*args, show=True, **kwargs):
        [1]: list plot
 
     """
-    from spb.defaults import TWO_D_B
-
     series = []
 
     if (
@@ -1909,8 +1919,8 @@ def plot_list(*args, show=True, **kwargs):
                 )
             series.append(List2DSeries(*a, **kwargs))
 
-    kwargs.setdefault("backend", TWO_D_B)
-    p = Plot(*series, **kwargs)
+    Backend = kwargs.pop("backend", TWO_D_B)
+    p = Backend(*series, **kwargs)
     if show:
         p.show()
     return p
@@ -2048,11 +2058,11 @@ def plot_piecewise(*args, **kwargs):
     ========
 
     .. plot::
-       :context: close-figs
+       :context: reset
        :format: doctest
        :include-source: True
 
-       >>> from sympy import symbols, cos, pi, Heaviside, Piecewise
+       >>> from sympy import symbols, sin, cos, pi, Heaviside, Piecewise
        >>> from spb import plot_piecewise
        >>> x = symbols('x')
 
@@ -2070,7 +2080,7 @@ def plot_piecewise(*args, **kwargs):
        [2]: list plot
        [3]: list plot
 
-    Multiple plots with different ranges and custom labels.
+    Plot multiple expressions.
 
     .. plot::
        :context: close-figs
@@ -2112,7 +2122,6 @@ def plot_piecewise(*args, **kwargs):
     plot_implicit, plot_geometry, plot_list
 
     """
-    from spb.defaults import TWO_D_B
     Backend = kwargs.pop("backend", TWO_D_B)
 
     args = _plot_sympify(args)
