@@ -14,12 +14,7 @@ from sympy.core.relational import (
     Relational, StrictLessThan, StrictGreaterThan,
 )
 from sympy.logic.boolalg import BooleanFunction
-from sympy.utilities.iterables import ordered
 from sympy.utilities.lambdify import lambdify
-from sympy.plotting.experimental_lambdify import (
-    vectorized_lambdify,
-    experimental_lambdify,
-)
 from sympy.plotting.intervalmath import interval
 from sympy.external import import_module
 import warnings
@@ -271,7 +266,11 @@ class BaseSeries:
     is_geometry = False
     # If True, it represents an object of the sympy.geometry module
 
-    def __init__(self):
+    use_cm = True
+    # Some series might use a colormap as default coloring. Setting this
+    # attribute to False will inform the backends to use solid color.
+
+    def __init__(self, *args, **kwargs):
         super().__init__()
 
     @property
@@ -346,9 +345,11 @@ class BaseSeries:
         return a
 
     def get_data(self):
-        """All child series should implement this method to return the
-        numerical data (of type float) which can be used by a plotting
-        library.
+        """Compute and returns the numerical data.
+
+        The number of parameters returned by this method depends on the
+        specific instance. If ``s`` is the series, make sure to read
+        ``help(s.get_data)`` to understand what it returns.
         """
         raise NotImplementedError
 
@@ -372,6 +373,7 @@ class Line2DBaseSeries(BaseSeries):
         self.adaptive_goal = kwargs.get("adaptive_goal", 0.01)
         self.loss_fn = kwargs.get("loss_fn", None)
         self._rendering_kw = kwargs.get("line_kw", dict())
+        self.use_cm = kwargs.get("use_cm", True)
 
     def get_data(self):
         """Return coordinates for plotting the line.
@@ -481,9 +483,6 @@ class LineOver1DRangeSeries(Line2DBaseSeries):
             try:
                 w = complex(f(x + 1j * imag))
                 return w.real, w.imag
-            except TypeError:
-                w = complex(f(x))
-                return w.real, w.imag
             except (ZeroDivisionError, OverflowError):
                 return np.nan, np.nan
 
@@ -773,6 +772,7 @@ class SurfaceBaseSeries(BaseSeries):
         self.loss_fn = kwargs.get("loss_fn", None)
         self.modules = kwargs.get("modules", None)
         self._rendering_kw = kwargs.get("surface_kw", dict())
+        self.use_cm = kwargs.get("use_cm", True)
 
     def _discretize(self, s1, e1, s2, e2):
         np = import_module('numpy')
@@ -878,6 +878,7 @@ class ParametricSurfaceSeries(SurfaceBaseSeries):
         self.start_v = float(var_start_end_v[1])
         self.end_v = float(var_start_end_v[2])
         self.label = label
+        self.use_cm = kwargs.get("use_cm", True)
 
         if self.adaptive:
             # NOTE: turns out that it is difficult to interpolate over 3
@@ -990,7 +991,7 @@ class ImplicitSeries(BaseSeries):
         self.yscale = kwargs.get("yscale", "linear")
         self._rendering_kw = kwargs.get("contour_kw", dict())
 
-        if isinstance(expr, BooleanFunction):
+        if isinstance(expr, BooleanFunction) and (not self.adaptive):
             self.adaptive = True
             warnings.warn(
                 "The provided expression contains Boolean functions. "
@@ -1043,28 +1044,44 @@ class ImplicitSeries(BaseSeries):
         )
 
     def get_data(self):
-        func = experimental_lambdify(
-            (self.var_x, self.var_y), self.expr, use_interval=True
-        )
-        xinterval = interval(self.start_x, self.end_x)
-        yinterval = interval(self.start_y, self.end_y)
-        try:
-            func(xinterval, yinterval)
-        except AttributeError:
-            # XXX: AttributeError("'list' object has no attribute 'is_real'")
-            # That needs fixing somehow - we shouldn't be catching
-            # AttributeError here.
-            if self.adaptive:
+        if self.adaptive:
+            import sympy.plotting.intervalmath.lib_interval as li
+
+            # HACK: this is necessary for sympy.plotting.intervalmath to
+            # work properly
+            from sympy.printing.pycode import PythonCodePrinter, SymPyPrinter
+            new_operators = {'and': '&', 'or': '|', 'not': 'not'}
+            tmp_operators_1 = PythonCodePrinter._operators
+            tmp_operators_2 = SymPyPrinter._operators
+            PythonCodePrinter._operators = new_operators
+            SymPyPrinter._operators = new_operators
+
+            keys = [t for t in dir(li) if ("__" not in t) and (t not in ["import_module", "interval"])]
+            vals = [getattr(li, k) for k in keys]
+            d = {k: v for k, v in zip(keys, vals)}
+            func = lambdify((self.var_x, self.var_y), self.expr, modules=[d, "math", "sympy"])
+
+            try:
+                data = self._get_raster_interval(func)
+            except (AttributeError, TypeError):
+                # XXX: AttributeError("'list' object has no attribute 'is_real'")
+                # That needs fixing somehow - we shouldn't be catching
+                # AttributeError here.
                 warnings.warn(
                     "Adaptive meshing could not be applied to the"
-                    " expression. Using uniform meshing."
-                )
-            self.adaptive = False
+                    " expression. Using uniform meshing.")
+                self.adaptive = False
+            finally:
+                # HACK: restore the original class attribute so that
+                # further calls to lambdify works as expected
+                PythonCodePrinter._operators = tmp_operators_1
+                SymPyPrinter._operators = tmp_operators_2
 
-        if self.adaptive:
-            return self._get_raster_interval(func)
-        else:
-            return self._get_meshes_grid()
+            if self.adaptive:
+                return data
+
+        # if adaptive=False
+        return self._get_meshes_grid()
 
     def _get_raster_interval(self, func):
         """Uses interval math to adaptively mesh and obtain the plot"""
@@ -1159,7 +1176,7 @@ class ImplicitSeries(BaseSeries):
         xarray = self._discretize(self.start_x, self.end_x, self.n1, self.xscale)
         yarray = self._discretize(self.start_y, self.end_y, self.n2, self.yscale)
         x_grid, y_grid = np.meshgrid(xarray, yarray)
-        func = vectorized_lambdify((self.var_x, self.var_y), expr)
+        func = lambdify((self.var_x, self.var_y), expr)
         z_grid = func(x_grid, y_grid)
         z_grid = self._correct_size(z_grid, x_grid)
         z_grid[np.ma.where(z_grid < 0)] = -1
@@ -1203,18 +1220,19 @@ class ImplicitSeries(BaseSeries):
 
 class InteractiveSeries(BaseSeries):
     """Base class for interactive series, in which the expressions can be
-    either a line or a surface (parametric or not). On top of the usual
-    ranges (x, y or u, v, which must be provided), the expressions can use
-    any number of parameters. The following class, together with the
-    interactive.py module, makes it possible to easily plot symbolic
-    expressions with interactive widgets.
+    either a line, a surface (parametric or not), a vector field, ...
+    On top of the usual ranges (x, y or u, v, which must be provided), the
+    expressions can use any number of parameters.
 
-    Once new parameters are available, execute the update_data(params)
-    method, passing in a dictionary with all the necessary parameters. Then,
-    get_data() can be called.
+    The following class, together with the `interactive.py` module, makes it
+    possible to easily plot symbolic expressions with interactive widgets.
+
+    Once new parameters are available, update them by setting the ``params``
+    attribute with a dictionary with all the necessary parameters. Then,
+    ``get_data()`` can be called.
 
     Differently from non-interactive series, only uniform sampling is
-    implemented.
+    implemented here.
     """
     is_interactive = True
 
@@ -1274,6 +1292,7 @@ class InteractiveSeries(BaseSeries):
         self.only_integers = kwargs.get("only_integers", False)
         self.is_point = kwargs.get("is_point", False)
         self.is_filled = kwargs.get("is_filled", False)
+        self.use_cm = kwargs.get("use_cm", True)
 
         nexpr, npar = len(exprs), len(ranges)
 
@@ -1287,7 +1306,7 @@ class InteractiveSeries(BaseSeries):
 
         # NOTE: the expressions must have been sympified earlier.
         self.expr = exprs[0] if len(exprs) == 1 else Tuple(*exprs, sympify=False)
-        self.signature = list(ordered(self.expr.free_symbols))
+        self.signature = sorted(self.expr.free_symbols, key=lambda t: t.name)
 
         # Generate a list of lambda functions, two for each expression:
         # 1. the default one.
@@ -1352,12 +1371,7 @@ class InteractiveSeries(BaseSeries):
 
     @property
     def params(self):
-        """Return the current parameters' dictionary."""
-        return self._params
-
-    @params.setter
-    def params(self, p):
-        """Update the data based on the values of the parameters.
+        """Get or set the current parameters dictionary.
 
         Parameters
         ==========
@@ -1366,6 +1380,10 @@ class InteractiveSeries(BaseSeries):
             key: symbol associated to the parameter
             val: the value
         """
+        return self._params
+
+    @params.setter
+    def params(self, p):
         self._params = p
 
     def _str(self, series_type):
@@ -1759,6 +1777,7 @@ class ComplexSurfaceBaseSeries(BaseSeries):
         self.yscale = kwargs.get("yscale", "linear")
         self.modules = kwargs.get("modules", None)
         self.only_integers = kwargs.get("only_integers", False)
+        self.use_cm = kwargs.get("use_cm", True)
 
         # domain coloring mode
         self.coloring = kwargs.get("coloring", "a")
@@ -1939,7 +1958,7 @@ class ComplexInteractiveBaseSeries(InteractiveSeries, ComplexSurfaceBaseSeries):
         self._init_attributes(expr, r, label, **kwargs)
         self._check_fs([expr], [r], label, self._params)
 
-        self.signature = list(ordered(self.expr.free_symbols))
+        self.signature = sorted(self.expr.free_symbols, key=lambda t: t.name)
         # Two lambda functions:
         # 1. the default one.
         # 2. the backup one, in case of failures with the default one.
@@ -2119,6 +2138,7 @@ class VectorBase(BaseSeries):
         self.is_streamlines = kwargs.get("streamlines", False)
         self.modules = kwargs.get("modules", None)
         self.only_integers = kwargs.get("only_integers", False)
+        self.use_cm = kwargs.get("use_cm", True)
         if self.is_streamlines:
             self._rendering_kw = kwargs.get("stream_kw", dict())
         else:
@@ -2323,6 +2343,7 @@ class PlaneSeries(SurfaceBaseSeries):
         self.zscale = kwargs.get("zscale", "linear")
         self._params = params
         self._rendering_kw = kwargs.get("line_kw", dict())
+        self.use_cm = kwargs.get("use_cm", True)
 
     def __str__(self):
         return "plane series: %s over %s, %s, %s" % (
@@ -2450,6 +2471,7 @@ class GeometrySeries(BaseSeries):
         self._params = params
         self.is_filled = kwargs.get("is_filled", True)
         self.n = kwargs.get("n", 200)
+        self.use_cm = kwargs.get("use_cm", True)
         if isinstance(expr, (LinearEntity3D, Point3D)):
             self.is_3Dline = True
             self.start = 0
